function f = bci_plotERP(X, Y, P, vp, channel, effect, catX, catY,lp)

% bci_plotERP(X, Y, P, vp, channel, catX, catY, lp)
%
% bci_plotERP plots ERPs of two conditions or two contrasts
% and their difference wave in a given channel
%
%
% CATX and CATY server for proper titling. F is the figure handle.
% P is thevector of p-values infered from the bootstrapped samples
%
% lp is the lowpass cutoff for the difference plot 
%
% see also: MEAN, PLOT, LEGEND, SET
%
%   Author:
%   Boris Bernhardt  (boris@dunkelweiss.net)
%   Institute of Cognitive Science
%   Neurobiospychology Lab
%
%   Date:   January 31, 2006 // Lastly modified: 08/03/2007
%   GNU public licence. Information wants to be free!
%
%   16.01.07 switched axis
%   09.05.07 simplified and significance plot integrated
%   24.05.07 double contrasts integrated

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Unpack the cell arrays with the signals per subject


% keyboard

f = figure,

hold on
axis ij

% smoothing of the ERP:
% gauss=exp(-[-500:499].^2/(2*70^2));
% fERP1 = ifft(fftshift(gauss.*fftshift(fft(fERP1))));

Xmean = mean(X,2);
Ymean = mean(Y,2);
diff = mean(X,2)-mean(Y,2);

if lp > 0
        [b,a] = butter(9,lp/100,'low');
        Xmean = filter(b,a,Xmean);
        Ymean = filter(b,a,Ymean);
        diff = filter(b,a,diff);
        
    end


plot(Xmean,'b','LineWidth',2),              % we plot these twice for easy legend indexing
plot(Ymean ,'r','LineWidth',2)              % we plot these twice for easylegend indexing
plot(diff,'--k','LineWidth',2),

legend(catX,catY,'Difference','Location','Northwest')
plot(zeros(1,size(X,1)),'k','LineWidth',.5),

% single trial differences?
%    for vp_nr = 1:size(XCell,1)
%        plot(mean([XCell{vp_nr,1}, XCell{vp_nr,2}],2) - mean([YCell{vp_nr,1}, YCell{vp_nr,2}],2),'color',[0.8 0.8 0.8],'LineWidth',.5)
%    end


plot(Xmean,'b','LineWidth',2),              % we plot these twice for easy legend indexing
plot(Ymean ,'r','LineWidth',2)              % we plot these twice for easylegend indexing
plot(diff,'--k','LineWidth',2),

%plot 1 stdandard error = std(x)/sqrt(N)
Xstd = std(X,0,2)./sqrt(size(X,2));
Ystd = std(Y,0,2)./sqrt(size(Y,2));
plot(Xmean+Xstd,'b','LineWidth',.3)
plot(Xmean-Xstd,'b','LineWidth',.3)
plot(Ymean+Ystd,'r','LineWidth',.3)
plot(Ymean-Ystd,'r','LineWidth',.3)


%keyboard
% plot the color code for the p-value per sample point

% the following 2 rows will give a gradient to the green, depending on the
% p-value (bright green = 0.00..1 --> dark green = 0.05)

% P(find(P == 1)) = 0.1;
% P = P * 10;

i=1;
length(P)
for pstep = 1:(length(P)-1)
    for step = 1:ceil(size(X,1)/length(P))
        
        plot([i,i],[9,10],'color',[0 1-P(pstep) 0])
        i=i+1;
    end
    
end

for j = i:size(X,1)
plot([j,j],[9,10],'color',[0 1-P(pstep+1) 0])    
end




%titel & legend
title([' ERP ' catX ' vs ' catY ' ' channel ]);
xlabel('time in msec');
ylabel('Voltage in \mu V');
set(gca, 'XTick',0:50:300);
set(gca, 'XTickLabel',{'-500','-250', '0', '250', '500', '750', '1000'}); % , '1250', '1500','1750'});
set(gca,'XGrid','on')
axis([1 size(X,1) -10 10]);
%eeglab redraw