function bci_plotEffects(effect,name,channel,saveflag)

% bci_plotEffects(effect,vp,channel,saveflag)
%
% plots the contrast denoted by "effect" (vis, avc, avi), that is the ERPs
% of both conditions and the difference wave
%
% vp: can be a subject or a vector of subjects, over which the grand mean is build
% channel: one of the 32 channels
% saveflag: 0 for not saving / 1 for saving the resulting picture under
% outputPath
%
%   Written by Christian Mhl (cmuehl@gmail.net)
%   GNU public licence. Information wants to be free!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

INpath = [bci_path 'EEGdata/03_bl_corrected/'];
OUTpath = [bci_path 'EEGdata/05_plots/'];


alpha = 0.001;
nboot =  200;
lp = 40;

sprintf('Bootstrapping mit %i resampling trials',nboot)
sprintf('ERP is low-pass filtered with %i Hz.',lp)

file = dir([INpath '*' name '*.mat'])
file(1).name
load([INpath() file(1).name]);

for c = 1:length(channel)
    sprintf('Running analysis for channel %i.',channel(c))

    if strcmp(effect,'ton') % the effect of visual attention


        categoryX = ['tongue'];
        categoryY = ['relax'];

        X = [squeeze(tongue(:,:,channel(c)))];
        Y = [squeeze(relax(:,:,channel(c)))];


    elseif strcmp(effect,'rfr') % the effect of visual attention


        categoryX = ['right finger'];
        categoryY = ['relax'];

        X = [squeeze(rightfinger(:,:,channel(c)))];
        Y = [squeeze(relax(:,:,channel(c)))];

    elseif strcmp(effect,'lfr') % the effect of visual attention


        categoryX = ['left finger'];
        categoryY = ['relax'];

        X = [squeeze(leftfinger(:,:,channel(c)))];
        Y = [squeeze(relax(:,:,channel(c)))];
    
        elseif strcmp(effect,'rft') % the effect of visual attention


        categoryX = ['right foot'];
        categoryY = ['relax'];

        X = [squeeze(rightfoot(:,:,channel(c)))];
        Y = [squeeze(relax(:,:,channel(c)))];

    elseif strcmp(effect,'lft') % the effect of visuo-spatial attention on audio-visual attention (doublecontrast)

        categoryX = ['left foot'];
        categoryY = ['relax'];

        X = [squeeze(leftfoot(:,:,channel(c)))];
        Y = [squeeze(relax(:,:,channel(c)))];


    else 'The effect parameter was set wrong!'
    end % effect


    % to obtain the  difference plot with sign. values
    % do bootstrap


    % Preperatios for the simple contrast

    diff = mean(X',2) - mean(Y',2);

    % Bootstrap for the simple contrast
    BS = bootstrp(nboot,@bootstrp_diffWave,[X;Y]);

    'BS size'
    size(BS)


    % Calculation of the p-values for each sample point in my difference wave


    BS = sort(abs(BS));  % differences are only positive

    % for each timepoint find the p-value (how probable such a big value is!)
    for i = 1:length(diff)
        pvalue = find(BS(:,i)' >= abs(diff(i)),1)/nboot ;  % value is bigger than ..% of data & normalize it to values between 0 and 1
        %keyboard
        if pvalue >= 1 - alpha
            P(i) = 1 - pvalue;  % transform to the probability of such a big or bigger value in data
        elseif pvalue < 1 - alpha
            P(i) = 1;
        else
            P(i) = 0;
        end
    end


    f = bci_plotERP(X(:,101:400,:)', Y(:,101:400,:)', P(101:400), name, [' channel ' int2str(channel(c))], effect, categoryX, categoryY,lp);

    % save fig-, pdf-, and mat-files:
    % figs are saved in ERPplots/FiGS/'alpha'
    % pdfs are saved in ERPplots/'alpha'
    % mat-files are saved in ERPplots/ERPmats/'alpha'

    if saveflag == 1
        saveas(f, [OUTpath 'FIGS/' num2str(alpha) 'ERP_' effect '_' name '_' categoryX '_vs_' categoryY '_chan' digit2str(channel(c),2) '.fig'], 'fig');
        %         pdfout = [OUTpath num2str(alpha) 'ERP_' effect '_' name '_' categoryX '_vs_' categoryY '_chan' digit2str(channel(c),2) '.jpg']
        %         saveas(f, [OUTpath 'ERP_' effect '_' name '_' categoryX '_vs_' categoryY '_chan' digit2str(channel(c),2) '.jpg'], 'jpg');
        save([OUTpath 'ERPmats/' num2str(alpha) 'ERP_' effect '_' name '_' categoryX '_vs_' categoryY '_chan' digit2str(channel(c),2) '.mat'],'BS','pvalue');
    end

    clear X Y P diff BS

end % c

