function [tongue, rightfinger, leftfinger, rightfoot, leftfoot,relax,spec] = bci_removeBaseline(name,bl_period,hp,lp)

% [bl_corrected] = bci_removeBaseline(data,bl_period,hp,lp)
%
% computes the mean of the specified period for each trial and removes it
% from the respective trials -
%
% give the baseline period in negative values before stimulus presentation
% (e.g. [-50 -10] for the period from -50 ms to -10 ms before stimulus
% onset)
%
%
% written by Christian Mhl (cmuehl at gmail dot com) 02/08/2007
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bl_period = bl_period + 200;
INpath = [bci_path 'EEGdata/01_decoded/']
OUTpath = [bci_path 'EEGdata/03_bl_corrected/'];

file = dir([INpath '*' name '*.mat'])
file(1).name

condi = {'tongue',  'rightfinger' , 'leftfinger', 'rightfoot', 'leftfoot','relax'};

% load data into workspace
load([INpath file(1).name])



% the onset of the signal to be taken from the data
onset = 1;


spec.hp = hp;
spec.lp = lp;
spec.bl_period = bl_period;
spec.onset = onset;


for s = 1:6
    eval(['data =' condi{s} ';']);
    sprintf('Data - trials: %i , samples: %i , channels: %i .',size(data,1),size(data,2),size(data,3))

    bl_corrected = zeros(size(data,1),size(data,2),size(data,3));
    for chan_nr = 1:size(data,3)

        ch_data = squeeze(data(:,onset:size(data,2),chan_nr));

        if hp > 0
            % filter frequency has to be between 0 and 1 - 1 is
            % corresponding to half of the sample frequency
            [b,a] = butter(5,hp/100,'high');
            ch_data = filter(b,a,ch_data,[],2);
        end

        if lp > 0
            [b,a] = butter(5,lp/100,'low');
            ch_data = filter(b,a,ch_data,[],2);
        end


        ch_mean = mean(ch_data(:,bl_period(1):bl_period(2)),2);
        %        keyboard
        bl_corrected(:,:,chan_nr) = ch_data - repmat(ch_mean,1,size(ch_data,2));
        bl_corrected(:,1:100,chan_nr) = 0; % remove the eeg onset artifact
        if chan_nr == 1
            figure,plot(ch_data(1,:),'r'),hold on,plot(bl_corrected(1,:,chan_nr),'k')
            % figure,imagesc(ch_data - bl_corrected(:,:,chan_nr))
        end
    end
    eval([condi{s} '= bl_corrected;']);
end

save([OUTpath name] , 'tongue', 'rightfinger', 'leftfinger', 'rightfoot', 'leftfoot','relax','spec','-v6');
